@@ -10,6 +10,7 @@ class MyTestCase(unittest.TestCase):
 
         self.test_fa = get_test_data("McrA_eval.faa")
         self.test_fq = get_test_data("test_TarA.1.fq")
+        self.troublesome_fa = get_test_data("fasta_parser_test.fasta")
         return
 
     def tearDown(self) -> None:
@@ -71,9 +72,15 @@ class MyTestCase(unittest.TestCase):
 
     def test_read_fasta_to_dict(self):
         from treesapp.fasta import read_fasta_to_dict
+
+        # Test normal functionality with a fasta file
         fa_dict = read_fasta_to_dict(self.test_fa)
         self.assertEqual(236, len(fa_dict))
 
+        # Test reading a file that doesn't exist
+        self.assertEqual({}, read_fasta_to_dict("./fake_file.fa"))
+        return
+
     def test_split_fa_size(self):
         from treesapp.fasta import split_fa, read_fasta_to_dict
         split_files = split_fa(fastx=self.test_fa, outdir="./", file_num=4)
@@ -97,6 +104,12 @@ class MyTestCase(unittest.TestCase):
         split_files = fq2fa(fastx=self.test_fq, outdir="./", max_seq_count=6)
         self.assertEqual(2, len(split_files))
 
+    def test_format_read_fasta(self):
+        from treesapp.fasta import format_read_fasta
+        fasta_dict = format_read_fasta(fasta_input=self.troublesome_fa, molecule="prot", min_seq_length=50)
+        self.assertEqual(5, len(fasta_dict))
+        return
+
 
 if __name__ == '__main__':
     unittest.main()
