@@ -26,7 +26,7 @@ Use '-h' to get subcommand-specific help, e.g.
 """
 
 
-def main():
+def main(sys_args=None) -> int:
     commands = {"create": create,
                 "evaluate": evaluate,
                 "abundance": abundance,
@@ -40,8 +40,9 @@ def main():
                 "package": package}
     parser = argparse.ArgumentParser(description='Phylogenetic classification of biological sequences')
     parser.add_argument('command', nargs='?')
-    args = parser.parse_args(sys.argv[1:2])
-
+    if not sys_args:
+        sys_args = sys.argv
+    args = parser.parse_args(sys_args[1:2])
     if not args.command:
         sys.stderr.write(usage)
         sys.exit(1)
@@ -52,9 +53,9 @@ def main():
         sys.exit(1)
 
     cmd = commands.get(args.command)
-    cmd(sys.argv[2:])
+    cmd(sys_args[2:])
     logging.info("TreeSAPP has finished successfully.\n")
-    # TODO: Write citation info for all tools used
+    return 0
 
 
 if __name__ == '__main__':
