@@ -184,6 +184,43 @@ class Cluster:
         return info_string
 
 
+class BlastAln:
+    def __init__(self):
+        self.subject = ""
+        self.query = ""
+        self.start = 0
+        self.end = 0
+        self.alnlen = 0
+        self.gapopen = 0
+        self.mismatch = 0
+        self.qstart = 0
+        self.qend = 0
+        self.tstart = 0
+        self.tend = 0
+        self.evalue = 0.0
+        self.pident = 0.0
+        self.bits = 0.0
+
+    def load_blast_tab(self, line: str, sep="\t") -> None:
+        try:
+            fields = line.strip().split(sep)
+        except ValueError:
+            logging.error("Unable to parse line in from alignment table:\n{}\n".format(line))
+            sys.exit(7)
+
+        try:
+            self.subject, self.query = fields[0], fields[1]
+            self.pident, self.alnlen, self.mismatch, self.gapopen = fields[2:6]
+            self.qstart, self.qend, self.tstart, self.tend = fields[6:10]
+            self.evalue, self.bits = fields[10], fields[11]
+        except ValueError:
+            logging.error("Incorrect format for line in alignment file. Twelve were expected, found {}.\n{}\n"
+                          "".format(len(fields), line))
+            sys.exit(7)
+
+        return
+
+
 class MyFormatter(logging.Formatter):
 
     error_fmt = "%(levelname)s - %(module)s, line %(lineno)d:\n%(message)s"
@@ -223,13 +260,14 @@ class MyFormatter(logging.Formatter):
         return result
 
 
-def prep_logging(log_file_name=None, verbosity=False) -> None:
+def prep_logging(log_file=None, verbosity=False, stream=sys.stderr) -> None:
     """
     Allows for multiple file handlers to be added to the root logger, but only a single stream handler.
     The new file handlers must be removed outside of this function explicitly
 
-    :param log_file_name:
-    :param verbosity:
+    :param log_file: Path to a file to write the TreeSAPP log
+    :param verbosity: Whether debug-level information should be written (True) or not (False)
+    :param stream: Which stream, sys.stdout or sys.stderr, should the console logger write to?
     :return: None
     """
     if verbosity:
@@ -237,32 +275,34 @@ def prep_logging(log_file_name=None, verbosity=False) -> None:
     else:
         logging_level = logging.INFO
 
-    # Detect whether a handlers are already present and return if true
+    # Detect whether handlers are already present and return if true
     logger = logging.getLogger()
     if len(logger.handlers):
         return
 
     formatter = MyFormatter()
     # Set the console handler normally writing to stdout/stderr
-    ch = logging.StreamHandler()
-    ch.setLevel(logging_level)
-    ch.terminator = ''
-    ch.setFormatter(formatter)
+    console_handler = logging.StreamHandler(stream=stream)
+    console_handler.setLevel(logging_level)
+    console_handler.terminator = ''
+    console_handler.setFormatter(formatter)
 
-    if log_file_name:
-        output_dir = os.path.dirname(log_file_name)
+    if log_file:
+        if not os.path.isabs(log_file):
+            log_file = os.path.join(os.getcwd(), os.path.dirname(log_file), os.path.basename(log_file))
+        output_dir = os.path.dirname(log_file)
         try:
             if output_dir and not os.path.isdir(output_dir):
-                os.makedirs(output_dir)
+                os.mkdir(output_dir)
         except (IOError, OSError):
             sys.stderr.write("ERROR: Unable to make directory '" + output_dir + "'.\n")
             sys.exit(3)
         logging.basicConfig(level=logging.DEBUG,
-                            filename=log_file_name,
+                            filename=log_file,
                             filemode='w',
                             datefmt="%d/%m %H:%M:%S",
                             format="%(asctime)s %(levelname)s:\n%(message)s")
-        logging.getLogger('').addHandler(ch)
+        logging.getLogger('').addHandler(console_handler)
         logging.getLogger('').propagate = False
     else:
         logging.basicConfig(level=logging_level,
@@ -563,7 +603,7 @@ class TreeSAPP:
             dependencies += ["bwa"]
 
         if self.command in ["create", "update", "train", "evaluate"]:
-            dependencies += ["vsearch", "mafft"]
+            dependencies += ["mmseqs", "mafft"]
             if hasattr(args, "fast") and args.fast:
                 dependencies.append("FastTree")
 
@@ -656,9 +696,9 @@ class Updater(TreeSAPP):
         self.combined_fasta = ""  # Holds the newly identified candidate reference sequences and the original ref seqs
         self.old_ref_fasta = ""  # Contains only the original reference sequences
         self.cluster_input = ""  # Used only if resolve is True
-        self.uclust_prefix = ""  # Used only if resolve is True
+        self.clusters_prefix = ""  # Used only if resolve is True
         self.updated_refpkg_path = ""
-        self.rank_depth_map = None
+        # self.rank_depth_map = None
         self.prop_sim = 1.0
         self.min_length = 0  # The minimum sequence length for a classified sequence to be included in the refpkg
         self.updated_refpkg = ReferencePackage()
@@ -725,8 +765,8 @@ class Creator(TreeSAPP):
         self.hmm_purified_seqs = ""  # If an HMM profile of the gene is provided its a path to FASTA with homologs
         self.filtered_fasta = ""
         self.hmm_profile = ""  # HMM profile used for screening the input sequences
-        self.uclust_prefix = ""  # FASTA file prefix for cluster centroids
-        self.uc = ""  # UCLUST-specific output file defining the clusters, members, representatives, etc.
+        self.clusters_prefix = ""  # FASTA file prefix for cluster centroids
+        self.clusters_table = ""  # Output file defining the clusters, members, representatives, and similarity
         self.cluster_input = ""  # Name of the file to be used for clustering
         self.unaln_ref_fasta = ""  # FASTA file of unaligned reference sequences
         self.phylip_file = ""  # Used for building the phylogenetic tree with RAxML
@@ -1213,7 +1253,7 @@ class Evaluator(TreeSAPP):
 
         for depth in sorted(self.rank_depth_map):
             rank = self.rank_depth_map[depth]
-            if rank == "Cellular organisms":
+            if rank == "root":
                 continue
             taxonomic_distance = dict()
             n_queries, n_classified, sensitivity = self.get_sensitivity(rank)
@@ -1228,10 +1268,6 @@ class Evaluator(TreeSAPP):
                 for assignments in rank_assigned_dict[rank]:
                     for classified in assignments:
                         acc += 1
-                        if classified.split("; ")[0] == "Cellular organisms":
-                            logging.error("Lineage string cleaning has gone awry somewhere. "
-                                          "The root rank should be a Kingdom (e.g. Bacteria or Archaea) but nope.\n")
-                            sys.exit(21)
                         optimal, query = assignments[classified]
                         if optimal == classified:
                             offset = 0
