@@ -38,7 +38,7 @@ from treesapp.assign import abundify_tree_saps, delete_files, prep_reference_pac
 from treesapp.jplace_utils import sub_indices_for_seq_names_jplace, jplace_parser, demultiplex_pqueries
 from treesapp.clade_exclusion_evaluator import pick_taxonomic_representatives, select_rep_seqs,\
     map_seqs_to_lineages, prep_graftm_ref_files, build_graftm_package, map_headers_to_lineage, graftm_classify,\
-    determine_containment, parse_distances, load_rank_depth_map, get_testable_lineages_for_rank
+    determine_containment, parse_distances, get_testable_lineages_for_rank
 
 
 def info(sys_args):
@@ -136,7 +136,7 @@ Use '-h' to get subcommand-specific help, e.g.
     if not os.path.isdir(args.output):
         os.mkdir(args.output)
 
-    classy.prep_logging(os.path.join(args.output, 'TreeSAPP_package_log.txt'))
+    classy.prep_logging(log_file=os.path.join(args.output, 'TreeSAPP_package_log.txt'), stream=sys.stdout)
 
     for refpkg_pkl in args.pkg_path:
         refpkg.f__json = refpkg_pkl
@@ -504,12 +504,14 @@ def create(sys_args):
                               fasta_name=ts_create.cluster_input,
                               headers=list(fasta_records.keys()))
         if args.cluster:
-            wrapper.cluster_sequences(ts_create.executables["vsearch"], ts_create.cluster_input,
-                                      ts_create.uclust_prefix, ts_create.ref_pkg.pid)
-            ts_create.uc = ts_create.uclust_prefix + ".uc"
+            wrapper.cluster_sequences(software_path=ts_create.executables["mmseqs"],
+                                      fasta_input=ts_create.cluster_input, output_prefix=ts_create.clusters_prefix,
+                                      similarity=ts_create.ref_pkg.pid, num_threads=args.num_threads)
+            ts_create.clusters_table = ts_create.clusters_prefix + "_cluster.tsv"
+            cluster_alignments = ts_create.clusters_prefix + "_cluster_aln.tsv"
         # Read the uc file if present
-        if ts_create.uc:
-            cluster_dict = file_parsers.read_uc(ts_create.uc)
+        if ts_create.clusters_table and cluster_alignments:
+            cluster_dict = file_parsers.create_mmseqs_clusters(ts_create.clusters_table, cluster_alignments)
 
             # Revert headers in cluster_dict from 'formatted' back to 'original'
             fasta.rename_cluster_headers(cluster_dict, ref_seqs.header_registry)
@@ -524,7 +526,7 @@ def create(sys_args):
         ##
         # Swap sequences in 'guarantee' for the representatives, creating new clusters
         ##
-        if args.guarantee and ts_create.uc:
+        if args.guarantee and ts_create.clusters_table:
             # We don't want to make the tree redundant so instead of simply adding the sequences in guarantee,
             #  we will swap them for their respective representative sequences.
             # All important sequences become representative, even if multiple are in the same cluster
@@ -534,11 +536,11 @@ def create(sys_args):
         ##
         # Set the cluster-specific values for ReferenceSequence objects
         ##
-        if ts_create.uc and not args.headless:
+        if ts_create.clusters_table and not args.headless:
             # Allow user to select the representative sequence based on organism name, sequence length and similarity
             create_refpkg.present_cluster_rep_options(cluster_dict, fasta_records, ref_seqs.header_registry,
                                                       ref_seqs.amendments)
-        elif ts_create.uc and args.headless:
+        elif ts_create.clusters_table and args.headless:
             create_refpkg.finalize_cluster_reps(cluster_dict, fasta_records, ref_seqs.header_registry)
         else:
             pass
@@ -856,11 +858,12 @@ def update(sys_args):
         # not all clustering tools + versions keep whole header - spaces are replaced with underscores
         fasta.write_new_fasta(fasta_dict=combined_fasta.fasta_dict,
                               fasta_name=ts_updater.cluster_input)
-        wrapper.cluster_sequences(ts_updater.executables["vsearch"], ts_updater.cluster_input,
-                                  ts_updater.uclust_prefix, ts_updater.prop_sim)
-        ts_updater.uc = ts_updater.uclust_prefix + ".uc"
+        wrapper.cluster_sequences(ts_updater.executables["mmseqs"], ts_updater.cluster_input,
+                                  ts_updater.clusters_prefix, ts_updater.prop_sim)
+        clusters_table = ts_updater.clusters_prefix + "_cluster.tsv"
+        cluster_alignments = ts_updater.clusters_prefix + "_cluster_aln.tsv"
 
-        cluster_dict = file_parsers.read_uc(ts_updater.uc)
+        cluster_dict = file_parsers.create_mmseqs_clusters(clusters_tbl=clusters_table, aln_tbl=cluster_alignments)
 
         # Revert headers in cluster_dict from 'formatted' back to 'original'
         fasta.rename_cluster_headers(cluster_dict, combined_fasta.header_registry)
@@ -1469,7 +1472,8 @@ def evaluate(sys_args):
     treesapp_args.check_parser_arguments(args, sys_args)
     treesapp_args.check_evaluate_arguments(ts_evaluate, args)
     ts_evaluate.decide_stage(args)
-    load_rank_depth_map(ts_evaluate)
+    ts_evaluate.rank_depth_map = {ts_evaluate.ref_pkg.taxa_trie.accepted_ranks_depths[rank_name]: rank_name for
+                                  rank_name in ts_evaluate.ref_pkg.taxa_trie.accepted_ranks_depths}
 
     ref_leaves = ts_evaluate.ref_pkg.generate_tree_leaf_references_from_refpkg()
     ref_lineages = {leaf.number: leaf.lineage for leaf in ref_leaves}
@@ -1512,11 +1516,7 @@ def evaluate(sys_args):
         else:
             min_seq_length = str(30)
 
-        # validate_ref_package_files(refpkg, ts_evaluate.output_dir)
-
-        ranks = {"domain": 0, "phylum": 1, "class": 2, "order": 3, "family": 4, "genus": 5, "species": 6}
         for rank in args.taxon_rank:
-            depth = ranks[rank]
             for lineage in get_testable_lineages_for_rank(ref_lineages, rep_accession_lineage_map, rank):
                 # Select representative sequences belonging to the taxon being tested
                 taxon_rep_seqs = select_rep_seqs(representative_seqs, fasta_records, lineage)
@@ -1546,25 +1546,21 @@ def evaluate(sys_args):
                     gpkg_path = intermediates_path + test_refpkg_prefix + ".gpkg"
 
                     if not os.path.isfile(classification_table):
-                        # GraftM refpkg input paths:
-                        filtered_gpkg_tax_ids = intermediates_path + "tax_ids_" + ts_evaluate.ref_pkg.prefix + ".txt"
-                        filtered_mfa = intermediates_path + ts_evaluate.ref_pkg.prefix + ".mfa"
-                        filtered_fasta = intermediates_path + ts_evaluate.ref_pkg.prefix + ".fa"
                         # GraftM refpkg output files:
                         gpkg_refpkg_path = gpkg_path + os.sep + test_refpkg_prefix + ".gpkg.refpkg" + os.sep
                         gpkg_tax_ids_file = gpkg_refpkg_path + ts_evaluate.ref_pkg.prefix + "_taxonomy.csv"
 
                         # Copy reference files, then exclude all clades belonging to the taxon being tested
-                        prep_graftm_ref_files(intermediate_dir=intermediates_path,
-                                              target_taxon=lineage,
-                                              refpkg=ts_evaluate.ref_pkg,
-                                              depth=depth)
+                        output_paths = prep_graftm_ref_files(tmp_dir=intermediates_path,
+                                                             target_clade=lineage,
+                                                             refpkg=ts_evaluate.ref_pkg,
+                                                             executables=ts_evaluate.executables)
 
                         if not os.path.isdir(gpkg_path):
                             build_graftm_package(gpkg_path=gpkg_path,
-                                                 tax_file=filtered_gpkg_tax_ids,
-                                                 mfa_file=filtered_mfa,
-                                                 fa_file=filtered_fasta,
+                                                 tax_file=output_paths["filtered_tax_ids"],
+                                                 mfa_file=output_paths["filtered_mfa"],
+                                                 fa_file=output_paths["filtered_fasta"],
                                                  threads=args.num_threads)
                         shutil.copy(gpkg_tax_ids_file, tax_ids_file)
                         # Write the query sequences
