@@ -209,12 +209,13 @@ def read_fasta_to_dict(fasta_file: str) -> dict:
     fasta_dict = dict()
 
     if not os.path.exists(fasta_file):
-        logging.error("'{}' fasta file doesn't exist.\n".format(fasta_file))
+        logging.debug("'{}' fasta file doesn't exist.\n".format(fasta_file))
+        return fasta_dict
 
     try:
         py_fa = Fasta(fasta_file, build_index=False, full_name=True)
     except RuntimeError as error:
-        logging.warning(str(error))
+        logging.debug(str(error)+"\n")
         return fasta_dict
 
     for name, seq in py_fa:  # type: (str, str)
@@ -746,58 +747,6 @@ def merge_fasta_dicts_by_index(extracted_seq_dict, numeric_contig_index):
     return merged_extracted_seq_dict
 
 
-def write_classified_sequences(tree_saps: dict, formatted_fasta_dict: dict, fasta_file: str) -> None:
-    """
-    Function to write the nucleotide sequences representing the full-length ORF for each classified sequence
-    Sequence names are from JPlace.contig_name values so output format is:
-
-     >contig_name|RefPkg|StartCoord_StopCoord
-
-    :param tree_saps: A dictionary of gene_codes as keys and TreeSap objects as values
-    :param formatted_fasta_dict: A dictionary with headers/sequence names as keys and sequences as values
-    :param fasta_file: Path to a file to write the sequences to in FASTA format
-    :return: None
-    """
-    output_fasta_dict = dict()
-    len_parsing_problem = False
-    prefix = ''  # For adding a '>' if the formatted_fasta_dict sequences have them
-    for seq_name in formatted_fasta_dict:
-        if seq_name[0] == '>':
-            prefix = '>'
-        break
-
-    for denominator in tree_saps:
-        for placed_sequence in tree_saps[denominator]:  # type JPlace
-            if placed_sequence.classified:
-                output_fasta_dict[placed_sequence.place_name] = ""
-                try:
-                    output_fasta_dict[placed_sequence.place_name] = formatted_fasta_dict[prefix +
-                                                                                         placed_sequence.place_name]
-                except KeyError:
-                    seq_name = re.sub(r"\|{0}\|\d+_\d+.*".format(placed_sequence.ref_name),
-                                      '',
-                                      placed_sequence.place_name)
-                    try:
-                        output_fasta_dict[placed_sequence.place_name] = formatted_fasta_dict[prefix + seq_name]
-                    except KeyError:
-                        logging.error("Unable to find '" + prefix + placed_sequence.place_name +
-                                      "' in predicted ORFs file!\nExample headers in the predicted ORFs file:\n\t" +
-                                      '\n\t'.join(list(formatted_fasta_dict.keys())[:6]) + "\n")
-                        sys.exit(3)
-
-                if not placed_sequence.seq_len:
-                    placed_sequence.seq_len = len(output_fasta_dict[placed_sequence.place_name])
-                    len_parsing_problem = True
-
-    if output_fasta_dict:
-        write_new_fasta(output_fasta_dict, fasta_file)
-
-    if len_parsing_problem:
-        logging.warning("Problem parsing homologous subsequence lengths from headers of classified sequences.\n")
-
-    return
-
-
 def format_fasta(fasta_input: str, molecule: str, output_fasta: str, min_seq_length=10) -> dict:
     """
     Reads a FASTA file, ensuring each sequence and sequence name is valid, and writes the valid sequence to a new FASTA.
@@ -813,9 +762,9 @@ def format_fasta(fasta_input: str, molecule: str, output_fasta: str, min_seq_len
 
     # Select the alphabet to use when determining whether there are any bad characters
     if molecule == "prot":
-        bad_chars = re.compile(r"[OU]")
+        bad_chars = re.compile(r"[OUou\d]")
     else:
-        bad_chars = re.compile(r"[EFIJLOPQZ]")
+        bad_chars = re.compile(r"[EFIJLOPQZefijlopqz\d]")
     bad_seqs = set()
 
     # Open the output FASTA for writing
@@ -884,9 +833,9 @@ def format_read_fasta(fasta_input: str, molecule: str, subset=None, min_seq_leng
     start = time()
 
     if molecule == "prot":
-        bad_chars = re.compile(r"[OU]")
+        bad_chars = re.compile(r"[OUou\d]")
     else:
-        bad_chars = re.compile(r"[EFIJLOPQZ]")
+        bad_chars = re.compile(r"[EFIJLOPQZefijlopqz\d]")
     bad_seqs = set()
 
     if subset and type(subset) is not set:
@@ -904,7 +853,7 @@ def format_read_fasta(fasta_input: str, molecule: str, subset=None, min_seq_leng
             if bad_chars.search(seq):
                 bad_seqs.add(name)
                 continue
-            formatted_fasta_dict[name] = seq
+            formatted_fasta_dict[name.rstrip()] = seq
     end = time()
     logging.debug("{} read by pyfastx in {} seconds.\n".format(fasta_input, end-start))
 
@@ -933,7 +882,14 @@ def get_headers(fasta_file: str) -> list:
         logging.error("'{}' fasta file doesn't exist.\n".format(fasta_file))
 
     n_headers = 0
-    for name, seq in Fasta(fasta_file, build_index=False, full_name=True):  # type: (str, str)
+    try:
+        fa = Fasta(file_name=fasta_file, build_index=False, full_name=True)
+    except RuntimeError:
+        logging.warning("Pyfastx is unable to open '{}' to read headers. "
+                        "There is a chance this is an empty file and will be skipped.\n".format(fasta_file))
+        return original_headers
+
+    for name, seq in fa:  # type: (str, str)
         n_headers += 1
         original_headers.append('>' + str(name))
 
@@ -1298,7 +1254,7 @@ def split_combined_ref_query_fasta(combined_msa, query_msa_file, ref_msa_file) -
     return
 
 
-def multiple_alignment_dimensions(mfa_file, seq_dict=None):
+def multiple_alignment_dimensions(mfa_file: str, seq_dict=None) -> (int, int):
     """
     Checks to ensure all sequences are the same length and returns a tuple of (nrow, ncolumn)
 
