@@ -695,6 +695,8 @@ class TaxonomicHierarchy:
                     break
                 else:
                     previous = taxon
+                if taxon.rank == "root":
+                    self.rooted = True
 
             # Update the number of lineages provided to TaxonomicHierarchy
             self.lineages_fed += 1
